@@ -3,12 +3,11 @@ package BioX::Wrapper::Annovar;
 #use 5.006;
 
 use Moose;
-#use Moose;
-#use File::Find::Rule;
-#use File::Basename;
-#use File::Path qw(make_path remove_tree);
-#use File::Find::Rule;
-#use Cwd;
+use File::Find::Rule;
+use File::Basename;
+use File::Path qw(make_path remove_tree);
+use File::Find::Rule;
+use Cwd;
 use IO::Uncompress::Gunzip;
 use Data::Dumper;
 
@@ -27,7 +26,7 @@ Version 0.06
 
 =cut
 
-our $VERSION = '0.35';
+our $VERSION = '0.39';
 
 
 =head1 SYNOPSIS
@@ -323,21 +322,6 @@ has 'annovar_cols' => (
         return $href;
     }
 );
-=head2 Wrapper Options
-
-=cut
-
-=head3 indir
-
-A path to your vcf files can be given, and using File::Find::Rule it will recursively search for vcf or vcf.gz  
-
-=cut
-
-has 'indir' => (
-    is => 'rw',
-    isa => 'Str|Undef',
-    required => 0,
-);
 
 =head3 vcfs
 
@@ -361,28 +345,6 @@ has 'vcfs' => (
     required => 0,
 );
 
-=head3 outdir
-
-Path to write out annotation files. It creates the structure
-
-    outdir
-        --annovar_interim
-        --annovar_final
-        --vcf-annotate_interim #If you choose to reannotate VCF file
-        --vcf-annotate_final #If you choose to reannotate VCF file
-
-A lot of interim files are created by annovar, and the only one that really matters unless you debugging a new database is the multianno file found in annovar_final
-
-If not given the outdirectory is assumed to be the current working directory.
-
-=cut
-
-has 'outdir' => (
-    is => 'rw',
-    isa => 'Str',
-    required => 1,
-    default => sub { return getcwd() },
-);
 
 
 =head3 annotate_vcf 
@@ -404,7 +366,8 @@ has 'annotate_vcf' => (
     required => 1,
 );
 
-#Internal Variables
+=head2 Internal Variables
+=cut
 
 has 'samples' => (
     is => 'rw',
